angular.module('app.controller', [])

.controller('HomeController', function($rootScope, $scope, $cordovaSocialSharing, $cordovaToast, Item) {
    $rootScope.$on("$routeChangeStart", function(){
        $rootScope.loading = true;
    });

    $rootScope.$on("$routeChangeSuccess", function(){
        $rootScope.loading = false;
    });

    $scope.items = Item.query();

    $scope.showLocation = function(item) {
        var url = 'http://maps.google.com/maps?q='
            + item.latitude + ',+' + item.longitude;
        window.open(url, '_system');
    };

    $scope.deleteItem = function(item) {
        Item.delete(item);
        $cordovaToast.showShortCenter('Gift Card deleted.');
    };

    $scope.shareTwitter = function(item) {
        var text = createText(item) + ' #NVCgift ';
        $cordovaSocialSharing.shareViaTwitter(text, item.imageSrc, null).then(function(result) {
            console.log('Finished sharing via Twitter: ' + result);
        }, function(err) {
            console.log('Error sharing via Twitter: ' + err);
        });
    };

    $scope.shareViaWhatsApp = function() {
        var text = createText(item);
        $cordovaSocialSharing.shareViaWhatsApp(text, item.imageSrc, null).then(function(result) {
            console.log('Finished sharing via WhatsApp: ' + result);
        }, function(err) {
            console.log('Error sharing via WhatsApp: ' + err);
        });
    };

    $scope.shareEmail = function(item) {
        var text = createText(item);
        $cordovaSocialSharing.shareViaEmail(text, 'NVC Gift Card', null, null, null, [item.imageSrc]).then(function(result) {
            console.log('Finished sharing via Email: ' + result);
        }, function(err) {
            console.log('Error sharing via Email: ' + err);
        });
    };

    $scope.shareFacebook = function(item) {
        var text = createText(item);
        window.plugins.socialsharing.shareVia(
            'com.facebook',
            text, // Message
            '', // Subject
            item.imageSrc, // Image
            null, // URL
            function() {}, // Success callback
            function(msg) {} // Error callback
        );
    };

    function createText(item) {
        return 'When I ' + (item.observationVerb.name || '') + ' ' 
            + (item.observation || '')
            + '. I feel ' + (item.feeling.name || '')
            + ' because I need ' + (item.need.name || '') + '.';
    }
})

.controller('CreateItemController', function($scope, $location, $cordovaCamera, $cordovaGeolocation, Item) {
    $scope.item = {
        observationVerb: observations[0],
        feeling: feelings[0],
        need: needs[0]
    };
    $scope.feelings = feelings;
    $scope.needs = needs;
    $scope.observations = observations;

    $cordovaGeolocation.getCurrentPosition().then(function(position) {
        $scope.item.latitude = position.coords.latitude;
        $scope.item.longitude = position.coords.longitude;
        $scope.item.timestamp = position.timestamp
    }, function(err) {
        console.log('Error getting current position: ' + err);
    });

    $scope.save = function() {
        Item.save($scope.item);
        $location.path('/');
    };

    $scope.takePicture = function() {
        var options = { 
            quality : 75, 
            destinationType : Camera.DestinationType.DATA_URL, 
            sourceType : Camera.PictureSourceType.CAMERA, 
            allowEdit : true,
            encodingType: Camera.EncodingType.JPEG,
            targetWidth: 500,
            targetHeight: 500,
            popoverOptions: CameraPopoverOptions,
            saveToPhotoAlbum: false
        };

        $cordovaCamera.getPicture(options).then(function(imageData) {
            var image = document.getElementById('giftCardImage');
            var imageSrc = "data:image/jpeg;base64," + imageData;
            image.src = imageSrc;
            $scope.item.imageSrc = imageSrc;
        }, function(err) {
            console.log('Taking pictures failed because: ' + err);
        });
    };

    $scope.loadPicture = function() {
        var options = { 
            quality : 75, 
            destinationType : Camera.DestinationType.DATA_URL, 
            sourceType : Camera.PictureSourceType.PHOTOLIBRARY, 
            allowEdit : true,
            encodingType: Camera.EncodingType.JPEG,
            targetWidth: 500,
            targetHeight: 500,
            popoverOptions: CameraPopoverOptions,
            saveToPhotoAlbum: false
        };

        $cordovaCamera.getPicture(options).then(function(imageData) {
            var image = document.getElementById('giftCardImage');
            var imageSrc = "data:image/jpeg;base64," + imageData;
            image.src = imageSrc;
            $scope.item.imageSrc = imageSrc;
        }, function(err) {
            console.log('Loading pictures failed because: ' + err);
        });
    }
})
